==> perfetto_53.0.orig.tar.gz: perfetto-53.0/src/trace_redaction/prune_perf_events.h <==
/*
 * Copyright (C) 2025 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SRC_TRACE_REDACTION_PRUNE_PERF_EVENTS_H_
#define SRC_TRACE_REDACTION_PRUNE_PERF_EVENTS_H_

#include <memory>

#include "src/trace_redaction/filtering.h"
#include "src/trace_redaction/trace_redaction_framework.h"

namespace perfetto::trace_redaction {

class PrunePerfEvents : public TransformPrimitive {
 public:
  base::Status Transform(const Context& context,
                         std::string* packet) const override;

  template <class Filter>
  void emplace_filter() {
    filter_ = std::make_unique<Filter>();
  }

 private:
  base::Status OnPerfSample(const Context& context,
                            uint64_t ts,
                            std::optional<int64_t> trace_packet_clock_id,
                            std::optional<int64_t> trusted_packet_sequence_id,
                            protozero::Field& field,
                            protos::pbzero::TracePacket* message) const;

  std::unique_ptr<PidFilter> filter_;
};

}  // namespace perfetto::trace_redaction

#endif  // SRC_TRACE_REDACTION_PRUNE_PERF_EVENTS_H_

==> perfetto_54.0.orig.tar.gz: perfetto-54.0/src/trace_redaction/prune_perf_events.h <==
/*
 * Copyright (C) 2025 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SRC_TRACE_REDACTION_PRUNE_PERF_EVENTS_H_
#define SRC_TRACE_REDACTION_PRUNE_PERF_EVENTS_H_

#include <cstdint>
#include <memory>
#include <optional>
#include <string>

#include "perfetto/base/status.h"
#include "perfetto/protozero/field.h"
#include "protos/perfetto/trace/trace_packet.pbzero.h"
#include "src/trace_redaction/filtering.h"
#include "src/trace_redaction/trace_redaction_framework.h"

namespace perfetto::trace_redaction {

class PrunePerfEvents : public TransformPrimitive {
 public:
  base::Status Transform(const Context& context,
                         std::string* packet) const override;

  template <class Filter>
  void emplace_filter() {
    filter_ = std::make_unique<Filter>();
  }

 private:
  base::Status OnPerfSample(const Context& context,
                            uint64_t ts,
                            std::optional<uint32_t> trace_packet_clock_id,
                            std::optional<int64_t> trusted_packet_sequence_id,
                            protozero::Field& field,
                            protos::pbzero::TracePacket* message) const;

  std::unique_ptr<PidFilter> filter_;
};

}  // namespace perfetto::trace_redaction

#endif  // SRC_TRACE_REDACTION_PRUNE_PERF_EVENTS_H_
